aboutsummaryrefslogtreecommitdiff
path: root/crypto-common/src
diff options
context:
space:
mode:
Diffstat (limited to 'crypto-common/src')
-rw-r--r--crypto-common/src/main/kotlin/app/passwordstore/crypto/CryptoHandler.kt8
1 files changed, 4 insertions, 4 deletions
diff --git a/crypto-common/src/main/kotlin/app/passwordstore/crypto/CryptoHandler.kt b/crypto-common/src/main/kotlin/app/passwordstore/crypto/CryptoHandler.kt
index f8995bf6..ea42af6d 100644
--- a/crypto-common/src/main/kotlin/app/passwordstore/crypto/CryptoHandler.kt
+++ b/crypto-common/src/main/kotlin/app/passwordstore/crypto/CryptoHandler.kt
@@ -14,13 +14,13 @@ import java.io.OutputStream
public interface CryptoHandler<Key> {
/**
* Decrypt the given [ciphertextStream] using a [secretKey] and [passphrase], and writes the
* resultant plaintext to [outputStream]. The returned [Result] should be checked to ensure it is
* **not** an instance of [com.github.michaelbull.result.Err] before the contents of
* [outputStream] are used.
*/
public fun decrypt(
- secretKey: Key,
+ keys: List<Key>,
passphrase: String,
ciphertextStream: InputStream,
outputStream: OutputStream,
@@ -14,13 +14,13 @@ import java.io.OutputStream
public interface CryptoHandler<Key> {
/**
- * Decrypt the given [ciphertextStream] using a [secretKey] and [passphrase], and writes the
- * resultant plaintext to [outputStream]. The returned [Result] should be checked to ensure it is
- * **not** an instance of [com.github.michaelbull.result.Err] before the contents of
+ * Decrypt the given [ciphertextStream] using a set of potential [keys] and [passphrase], and
+ * writes the resultant plaintext to [outputStream]. The returned [Result] should be checked to
+ * ensure it is **not** an instance of [com.github.michaelbull.result.Err] before the contents of
* [outputStream] are used.
*/